==> igniteui-react-charts-18.7.2.tgz: package/esm5/lib/PositiveVolumeIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { PositiveVolumeIndexIndicatorStrategy } from "./PositiveVolumeIndexIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var PositiveVolumeIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PositiveVolumeIndexIndicator, _super);
    function PositiveVolumeIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PositiveVolumeIndexIndicator.prototype.bi = function () {
        return new PositiveVolumeIndexIndicator();
    };
    PositiveVolumeIndexIndicator.prototype.get_abn = function () {
        return new PositiveVolumeIndexIndicatorStrategy();
    };
    Object.defineProperty(PositiveVolumeIndexIndicator.prototype, "abn", {
        get: function () {
            return this.get_abn();
        },
        enumerable: false,
        configurable: true
    });
    PositiveVolumeIndexIndicator.prototype.get_ab0 = function () {
        return PositiveVolumeIndexIndicator.$;
    };
    Object.defineProperty(PositiveVolumeIndexIndicator.prototype, "ab0", {
        get: function () {
            return this.get_ab0();
        },
        enumerable: false,
        configurable: true
    });
    PositiveVolumeIndexIndicator.$t = markType(PositiveVolumeIndexIndicator, 'PositiveVolumeIndexIndicator', StrategyBasedIndicator.$);
    return PositiveVolumeIndexIndicator;
}(StrategyBasedIndicator));
export { PositiveVolumeIndexIndicator };

==> igniteui-react-charts-19.0.0.tgz: package/esm5/lib/PositiveVolumeIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { PositiveVolumeIndexIndicatorStrategy } from "./PositiveVolumeIndexIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var PositiveVolumeIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PositiveVolumeIndexIndicator, _super);
    function PositiveVolumeIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PositiveVolumeIndexIndicator.prototype.bk = function () {
        return new PositiveVolumeIndexIndicator();
    };
    PositiveVolumeIndexIndicator.prototype.get_ab0 = function () {
        return new PositiveVolumeIndexIndicatorStrategy();
    };
    Object.defineProperty(PositiveVolumeIndexIndicator.prototype, "ab0", {
        get: function () {
            return this.get_ab0();
        },
        enumerable: false,
        configurable: true
    });
    PositiveVolumeIndexIndicator.prototype.get_acd = function () {
        return PositiveVolumeIndexIndicator.$;
    };
    Object.defineProperty(PositiveVolumeIndexIndicator.prototype, "acd", {
        get: function () {
            return this.get_acd();
        },
        enumerable: false,
        configurable: true
    });
    PositiveVolumeIndexIndicator.$t = markType(PositiveVolumeIndexIndicator, 'PositiveVolumeIndexIndicator', StrategyBasedIndicator.$);
    return PositiveVolumeIndexIndicator;
}(StrategyBasedIndicator));
export { PositiveVolumeIndexIndicator };
